@@ -34,6 +34,12 @@
 
 #include "config.h"
 
+/*
+ * This is needed to expose pthread_mutexattr_settype and PTHREAD_MUTEX_DEFAULT
+ * on older pthreads implementations
+ */
+#define _XOPEN_SOURCE 700
+
 #include "compat.h"
 
 #include <assert.h>
