@@ -378,7 +378,7 @@ load_module_from_file_inlock (const char *name,
 	/* If same module was loaded previously, just take over config */
 	if (prev != NULL) {
 		if (!name || prev->name || prev->config)
-			p11_debug ("duplicate module %s, using previous", path);
+			p11_debug ("duplicate module %s, using previous", name);
 		free_module_unlocked (mod);
 		mod = prev;
 
@@ -511,7 +511,6 @@ take_config_and_load_module_inlock (char **name,
 	if (isolated) {
 		if (remote) {
 			p11_message ("ignoring 'isolated' on module '%s' because 'remote' is set", *name);
-			isolated = false;
 		} else {
 			if (asprintf (&value, "|" BINDIR "/p11-kit remote '%s'", filename) < 0)
 				return_val_if_reached (CKR_DEVICE_ERROR);
